@@ -1,7 +1,7 @@
 package Bencher::Scenario::LevenshteinModules;
 
-our $DATE = '2015-10-08'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-10-18'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,6 +21,12 @@ our $scenario = {
         {
             fcall_template => "Text::LevenshteinXS::distance(<word1>, <word2>)",
         },
+        {
+            fcall_template => "Text::Levenshtein::Damerau::PP::pp_edistance(<word1>, <word2>)",
+        },
+        {
+            fcall_template => "Text::Levenshtein::Damerau::XS::xs_edistance(<word1>, <word2>)",
+        },
     ],
     datasets => [
         { name=>"a",       args => {word1=>"a"      , word2=>"aa"},      result => 1 },
@@ -44,7 +50,11 @@ Bencher::Scenario::LevenshteinModules - Benchmark various modules calculating th
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenario-LevenshteinModules), released on 2015-10-08.
+This document describes version 0.02 of Bencher::Scenario::LevenshteinModules (from Perl distribution Bencher-Scenario-LevenshteinModules), released on 2015-10-18.
+
+=head1 SYNOPSIS
+
+ % bencher -m LevenshteinModules [other options]...
 
 =head1 HOMEPAGE
 
